camelot.camelot.types.StoredImage

Package camelot :: Package camelot :: Package types :: Class StoredImage |
[hide private]
[frames] | no frames]

# Class StoredImage

source code

Class linking a PIL image and the location and filename where the image is stored

Instance Methods | [hide private]
__init__(self, image, location=None, filename=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
full_path(self) | source code
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, image, location=None, filename=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### full_path(self) | source code
Decorators: `@property`